const path = require("path");
const webpack = require("webpack");

const shouldBuildForProduction = process.env.NODE_ENV === "production" || process.env.NODE_ENV === "staging";

module.exports = {
    cache: true,

    resolve: {
        extensions: ['', '.js', '.json', '.jsx', '.ts', '.tsx'],
    },

    module: {
        loaders: [
            {
                test: /react-icons.*\.js$/,
                loader: "babel-loader",
            },
            {
                test: /.tsx?$/,
                loaders: [
                    "babel-loader",
                    "awesome-typescript-loader",
                ],
            },
            {
                test: /\.scss$/,
                loaders: [
                    "style-loader",
                    "css-loader",
                    "sass-loader",
                ],
            },
        ],
    },

    plugins: [
        new webpack.DefinePlugin({
            "process.env.NODE_ENV": JSON.stringify(
                process.env.NODE_ENV || "development"
            ),
        }),
        ...(shouldBuildForProduction
            ? [
                new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/),
                new webpack.optimize.CommonsChunkPlugin({
                    children: true,
                    minChunks: 2,
                    async: true,
                }),
                new webpack.LoaderOptionsPlugin({
                    minimize: true,
                    debug: false,
                }),
                new webpack.optimize.OccurrenceOrderPlugin(),
                new webpack.optimize.UglifyJsPlugin({
                    sourceMap: false,
                    mangle: true,
                }),
            ]
            : []
        ),
    ],
};
