import * as React from "react";
import * as faker from "faker";
import * as sorters from "../sorters";
import DataTable from "../";
faker.locale = "pt_BR";
const fakeDate = () => faker.date.past(30);
const fakeMoney = () => faker.random.number({ min: 880, max: 5000, precision: 0.05 });
const fakeMultiMoney = () => [fakeMoney(), fakeMoney(), fakeMoney()];
export function generateStandardFakeData(options = {}) {
    return generateRows([
        {
            label: "Índice",
            content: (i) => i,
            sort: (options.sortable && sorters.stringSorter) || undefined,
        },
        {
            label: "Nome",
            content: () => faker.name.findName(),
            sort: (options.sortable && sorters.stringSorter) || undefined,
        },
        {
            label: "Data de nascimento",
            content: fakeDate,
            computedNode: (v) => v.toLocaleDateString(),
            sort: (options.sortable && sorters.dateSorter) || undefined,
        },
        {
            label: "Idade",
            sort: (options.sortable && sorters.numberSorter) || undefined,
            content: () => faker.random.number({ min: 10, max: 45, precision: 1 }),
        },
        ...(options.subCells
            ? [
                {
                    label: "Comparecimentos",
                    computedNode: (v) => v.toLocaleDateString(),
                    content: () => [fakeDate(), fakeDate(), fakeDate()],
                },
            ]
            : []),
        {
            label: "Ticket médio",
            computedNode: (v) => v.toFixed(2),
            sort: (options.sortable && sorters.numberSorter) || undefined,
            content: (!options.subColumns && (options.subCells ? fakeMultiMoney : fakeMoney)) || undefined,
            subColumns: (options.subColumns && [
                {
                    label: "Crédito",
                    computedNode: (v) => v.toFixed(2),
                    content: options.subCells ? fakeMultiMoney : fakeMoney,
                    sort: (options.sortable && sorters.numberSorter) || undefined,
                },
                {
                    label: "Débito",
                    computedNode: (v) => v.toFixed(2),
                    content: options.subCells ? fakeMultiMoney : fakeMoney,
                    sort: (options.sortable && sorters.numberSorter) || undefined,
                },
                {
                    label: "Espécie",
                    computedNode: (v) => v.toFixed(2),
                    content: options.subCells ? fakeMultiMoney : fakeMoney,
                    sort: (options.sortable && sorters.numberSorter) || undefined,
                },
            ]) ||
                undefined,
        },
    ], options);
}
function descriptorToColumn(desc) {
    return {
        sort: desc.sort,
        label: desc.label,
        featured: desc.featured,
        className: desc.className,
        subColumns: desc.subColumns && desc.subColumns.map(descriptorToColumn),
    };
}
const categories = ["Cliente VIP", "Cliente comum", "Cliente ocasional"];
function flattenColumns(cols) {
    return cols.map((c) => (c.subColumns ? c.subColumns : [c])).reduce((arr, v) => [...arr, ...v], []);
}
function genSumRows(featuredRow) {
    return (rows) => {
        const reduced = rows.reduce((acc, row) => {
            let data = acc.data || row.data.map(c => (Object.assign({}, c)));
            if (acc.data) {
                for (let i = 0; i < data.length; i++) {
                    const cell = data[i];
                    if (cell) {
                        if (typeof cell.value === "number") {
                            cell.value += row.data[i].value;
                        }
                        else if (typeof cell.value === "string") {
                            cell.value = "Média " + (featuredRow ? "total" : `de ${row.category}`);
                        }
                    }
                }
            }
            return Object.assign({}, acc, { data });
        }, {
            id: featuredRow ? "total" : "total@" + rows[0].category,
            data: undefined,
        });
        for (const cell of reduced.data) {
            if (cell && typeof cell.value === "number") {
                cell.value /= rows.length;
            }
        }
        return reduced;
    };
}
export function generateRows(cols, options) {
    const columns = cols.map(descriptorToColumn);
    const flatColumns = flattenColumns(cols);
    const data = [...new Array(options.numberOfRows || 100)].map((_, i) => ({
        id: faker.random.uuid(),
        category: options.categorized ? faker.helpers.randomize(categories) : undefined,
        data: flatColumns.map(c => {
            const value = typeof c.content === "function" ? c.content(i) : c.content;
            return {
                value,
                selectable: options.selectable ? false : undefined,
                computedNode: !value || options.preComputeNodes ? undefined : c.computedNode,
                node: value && options.preComputeNodes && c.computedNode ? c.computedNode(value) : undefined,
            };
        }),
    }));
    const generatedData = {
        columns,
        data,
        totalFunction: options.totalFunction ? genSumRows() : undefined,
        featuredRow: options.featuredRow ? genSumRows(true)(data) : undefined,
    };
    return generatedData;
}
require("./styles.scss");
export class TestDataTable extends React.Component {
    constructor(props) {
        super(props);
        this.onSelect = (id, selected) => {
            const ids = Array.isArray(id) ? id : [id];
            const data = [...this.state.data];
            for (const id of ids) {
                const i = data.findIndex(r => r.id === id);
                data[i] = Object.assign({}, data[i], { selected });
            }
            this.setState({ data });
        };
        const data = generateStandardFakeData(this.props);
        this.state = Object.assign({}, data);
    }
    render() {
        return (React.createElement("div", { className: "scrollable" },
            React.createElement(DataTable, Object.assign({}, this.state, { virtualize: true, placeholder: React.createElement("div", null, "Carregando..."), onSelect: this.props.selectable ? this.onSelect : undefined }))));
    }
}
//# sourceMappingURL=index.js.map