import * as tslib_1 from "tslib";
import { autobind } from "core-decorators";
import * as React from "react";
import { styleSheetParser } from "./";
const lazyload = require("react-lazyload");
const lazyloadDecorator = lazyload.lazyload;
let DataRowComponent = class DataRowComponent extends React.PureComponent {
    generateCell(cell, i, nSiblings, siblingPos) {
        const node = cell && (cell.node
            || (cell.computedNode
                && (Array.isArray(cell.value) ? (cell.value.map(cell.computedNode)) : cell.computedNode(cell.value))) || cell.value);
        const isArray = Array.isArray(node);
        if (!isArray && siblingPos !== 0) {
            return null;
        }
        else {
            return (React.createElement("td", { key: `${i}@${siblingPos || 0}`, "data-col": i, rowSpan: isArray ? undefined : nSiblings, className: styleSheetParser.cellContent + " " + (cell && cell.className || "") }, isArray ? node[siblingPos] : node));
        }
    }
    onSelect(ev) {
        if (this.props.onSelect) {
            this.props.onSelect(this.props.id, ev.target.checked);
        }
    }
    validate(props) {
        if (process.env.NODE_ENV !== "production") {
            if (new Set(props.data.filter(Array.isArray).map(c => Array.isArray(c) && c.length || -1)).size > 1) {
                console.group("CubeDataTable warning");
                console.warn("Invalid row: array cells have different lengths");
                console.warn(props);
                console.groupEnd();
            }
        }
    }
    componentWillReceiveProps(nextProps) {
        if (nextProps !== this.props) {
            this.validate(nextProps);
        }
    }
    componentDidMount() {
        this.validate(this.props);
    }
    render() {
        const siblings = Math.max(...this.props.data.map(cell => cell && (cell.node ? (Array.isArray(cell.node)) : Array.isArray(cell.value)) ? (cell.node || cell.value).length : 1));
        return (React.createElement("tr", { key: this.props.id + "@" + this.props.sibling, "data-even": this.props.index % 2 === 0 ? true : undefined, className: (this.props.className || "")
                + " " + (this.props.className || "")
                + " " + (this.props.selected === false ? styleSheetParser.disabled : "")
                + " " + (this.props.index % 2 === 0 ? styleSheetParser.odd : styleSheetParser.even) },
            !this.props.sibling && this.props.onSelect ? (React.createElement("th", { rowSpan: siblings, className: styleSheetParser.selectHeader }, !this.props.hideSelect && this.props.onSelect ?
                React.createElement("input", { type: "checkbox", checked: this.props.selected, onChange: this.onSelect })
                : null)) : null,
            this.props.data.map((cell, j) => this.generateCell(cell, j, siblings, this.props.sibling || 0)).filter(cell => cell)));
    }
};
DataRowComponent = tslib_1.__decorate([
    autobind
], DataRowComponent);
export default DataRowComponent;
export const VirtualizedDataRow = lazyloadDecorator({ height: 35, offset: 200, once: true })(DataRowComponent);
//# sourceMappingURL=rows.js.map