import * as React from "react";
export declare type RowId = string | number;
export declare function isRootColumn(col: DataColumn | RootColumn): col is RootColumn;
export declare function rootColumnIndex(columns: BaseColumn[], i: number): number;
export declare function subColumnIndex(columns: BaseColumn[], i: number, rootIndex: number): number;
export interface CubeDataTableProps<Rows extends BasicRow[] = BasicRow[] | CategorizedRow[]> {
    columns: Column[];
    className?: string;
    hideSelects?: boolean;
    featuredRow?: DataRow;
    headerCellClassName?: string;
    placeholder?: React.ReactNode;
    data: Rows;
    totalFunction?: (rows: Rows, category: RowId | undefined) => DataRow;
    onSelect?: (id: RowId | RowId[], selected: boolean) => void;
    virtualize?: boolean;
}
export interface CubeDataTableState {
    ascendant: boolean;
    isSticky?: boolean;
    stickyRuleRow?: string;
    currentSortedColumn?: number;
    currentSorting?: SortFunction;
}
export declare type SortFunction = (el1: any, el2: any) => number;
export declare type DataRow = BasicRow | CategorizedRow;
export interface BasicRow {
    selected?: boolean;
    className?: string;
    id: RowId;
    categorized?: string;
    data: ReadonlyArray<DataCell | null>;
}
export interface CategorizedRow extends BasicRow {
    category: string;
}
export interface DataCell<T = any> {
    value: T;
    className?: string;
    node?: React.ReactNode;
    computedNode?: (t: T) => React.ReactNode;
}
export interface SheetCell extends DataCell {
}
export declare type Column = DataColumn | RootColumn;
export interface BaseColumn {
    label: string;
    featured?: boolean;
    className?: string;
}
export interface DataColumn extends BaseColumn {
    sort?: SortFunction;
}
export interface RootColumn extends BaseColumn {
    subColumns: DataColumn[];
}
export declare function loadExternalStyleSheet(extSheet: any): void;
export declare let styleSheetParser: Readonly<{
    [key: string]: string | undefined;
}>;
export declare function isCategorizedRow(row: CategorizedRow | BasicRow): row is CategorizedRow;
export declare function areCategorizedRows(rows: DataRow[]): rows is CategorizedRow[];
export default class CubeDataTable extends React.PureComponent<CubeDataTableProps, CubeDataTableState> {
    private stickyTable;
    private scrollableParent;
    private tableDom;
    private onRef(tableDom);
    private getScrollableParent(parentStack);
    private setScrollableParent(scrollable);
    private setStickyTablePosition();
    private windowHandleSticky();
    private scrollHandleSticky();
    private handleSticky(forceRerender?);
    private syncStickyTableStyle();
    constructor(props: CubeDataTableProps, context?: any);
    componentWillReceiveProps(nextProps: CubeDataTableProps): void;
    private validateRowsLength(props);
    private generateRuleRow(content);
    private renderRow(row, index, isTotal?);
    private generateCategorizedRows(rows);
    private sortData(data);
    private onSortRootColumn(colId);
    private onSort(rootColIndex, subColIndex?);
    private onSortSubColumn(rootColId, subColId);
    render(): JSX.Element | null;
    componentDidMount(): void;
    componentWillUnmount(): void;
    private removeScrollListeners();
    componentDidUpdate(): void;
    private onStickyTableRef(stickyHeader);
    private genHeader(sticky?);
    private getCurrentStickyRuleRow();
    private areAllRowsSelected(rows?);
    private toggleAllRows();
    private toggleAllGivenRows(rs?);
    private getHeaderElement();
    private renderTable();
}
